import RateLimit from 'express-rate-limit';

// Constants

export const MAX_LENGTHS = {
    username: 100,
    user_website: 200,
    message_body: 1000
};

export const DEFAULT_PORT = 8080;

export const DEFAULT_CORS = ["alloca.space", "www.alloca.space"];

export const DEFAULT_DOMAIN = "comments.alloca.space";

export const DEFAULT_DB_PATH = "ucs.db";

// functions

export function escapeHtml(unsafe) {
    return unsafe
        .replace(/&/g, "&amp;")
        .replace(/</g, "&lt;")
        .replace(/>/g, "&gt;")
        .replace(/"/g, "&quot;")
        .replace(/'/g, "&#039;");
}

// limiters

export const limiter = limit => RateLimit({
    windowMs: 1 * 60 * 1000,
    max: limit,
});


export default {
    MAX_LENGTHS,
    DEFAULT_PORT,
    DEFAULT_CORS,
    DEFAULT_DOMAIN,
    DEFAULT_DB_PATH,
    escapeHtml,
    limiter
};
